==> kimageannotator_0.3.2.orig.tar.gz: kImageAnnotator-0.3.2/translations/kImageAnnotator_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Anordnen</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Nach vorne bringen</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Nach vorne bringen</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Nach hinten schicken</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Nach hinten schicken</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Dieses auswählen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Ändern</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationSettings</name>
    <message>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Textfarbe</translation>
    </message>
    <message>
        <source>Font Size</source>
        <translation>Schriftgröße</translation>
    </message>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Sichtbarkeit von Rahmen und Füllungen</translation>
    </message>
    <message>
        <source>Starting Number</source>
        <translation>Anfangsnummer</translation>
    </message>
    <message>
        <source>Blur Radius</source>
        <translation>Unschärferadius</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Aufkleber</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Andere schließen</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Alles schließen</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Alle nach links schließen</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Alle nach rechts schließen</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Crop</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>B:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillTypePicker</name>
    <message>
        <source>No Border and No Fill</source>
        <translation>Kein Rahmen und keine Füllung</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Rahmen und Füllung</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Rahmen und keine Füllung</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Bild skalieren</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Seitenverhältnis beibehalten</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Breite:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Höhe:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Prozentzahl</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Stift</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Nummer</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Markierungsrechteck</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Markierungsellipse</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Markierungsstift</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Pfeil</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Doppelpfeil</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Strich</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Verschwommenheit</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rechteck</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Anzahlzeiger</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Aufkleber</translation>
    </message>
</context>
</TS>

==> kimageannotator_0.4.0.orig.tar.gz: kImageAnnotator-0.4.0/translations/kImageAnnotator_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Anordnen</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Nach vorne bringen</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Nach vorne bringen</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Nach hinten schicken</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Nach hinten schicken</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Dieses auswählen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Ändern</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationSettings</name>
    <message>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Textfarbe</translation>
    </message>
    <message>
        <source>Font Size</source>
        <translation>Schriftgröße</translation>
    </message>
    <message>
        <source>Starting Number</source>
        <translation>Anfangsnummer</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Andere schließen</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Alles schließen</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Alle nach links schließen</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Alle nach rechts schließen</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Crop</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>B:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation type="unfinished">Sichtbarkeit von Rahmen und Füllungen</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation type="unfinished">Rahmen und Füllung</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation type="unfinished">Rahmen und keine Füllung</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation type="unfinished">Kein Rahmen und keine Füllung</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Bild skalieren</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Seitenverhältnis beibehalten</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Breite:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Höhe:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Prozentzahl</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation type="unfinished">Aufkleber</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Stift</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Nummer</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Markierungsrechteck</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Markierungsellipse</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Markierungsstift</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Pfeil</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Doppelpfeil</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Strich</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Verschwommenheit</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rechteck</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Anzahlzeiger</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Aufkleber</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomIndicator</name>
    <message>
        <source>Zoom Level</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
